<?php

namespace HSchulz\CustomKeSearchHooks;

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

use TYPO3\CMS\Core\Utility\ExtensionManagementUtility;
use TYPO3\CMS\Core\Utility\GeneralUtility;

/**
 * This class implements a hook into the TYPO3 ke_search extension.
 *
 * @author Hauke Schulz <hauke27@gmail.com>
 */
class RegisterFluidcontentIndexer {

    /**
     * Name of this extension.
     * @var string
     */
    const EXTENSION_NAME = 'custom_ke_search_hooks';

    /*
     * Name of the icon file used to display this indexer in the backend.
     * @var string
     */
    const ICON_FILE = 'Icons/fluidcontent-indexer-icon.gif';

    /**
     * Description for the indexer that will appear in the backend.
     * @var string
     */
    const INDEXER_DESCRIPTION = 'Indexer for fluidcontent_content elements';

    /**
     * The content type (CType) of fluidcontent elements.
     * @var string
     */
    const INDEXER_TYPE = 'fluidcontent_content';

    /**
     * The TYPO3 ObjectManager.
     * @var \TYPO3\CMS\Extbase\Object\ObjectManagerInterface
     */
    private $objectManager = null;

    /**
     * Hook method used by ke_search to register indexer configurations.<br>
     * Creates an array containing the configuration and appends it to the
     * given $params array.
     *
     * @author Hauke Schulz <hauke27@gmail.com>
     * @param array $params An array containing all indexer configurations?
     * @param array $pObj The parent object?
     */
    function registerIndexerConfiguration(&$params, $pObj) {

        /* Gets the path to this extension */
        $path = ExtensionManagementUtility::extRelPath(self::EXTENSION_NAME);

        /* Add new indexer item to the list */
        $params['items'][] = array(
            self::INDEXER_DESCRIPTION,
            self::INDEXER_TYPE,
            $path . self::ICON_FILE
        );
    }

    /**
     * Hook method used by ke_search to register a custom indexer.<br>
     * This method creates an indexer instance and returns the status
     *
     * @param array $indexerConfig Configuration from TYPO3 Backend
     * @param array $indexerObject Reference to indexer class.
     *
     * @author Hauke Schulz <hauke27@gmail.com>
     * @return string Status for indexer run in the backend.
     */
    public function customIndexer(&$indexerConfig, &$indexerObject) {

        /* Prepare the output variable */
        $content = '';

        /* If the indexer configuration is ment for this indexer */
        if ($indexerConfig['type'] == self::INDEXER_TYPE) {

            /* Get an instance for the TYPO3 ObjectManager */
            $this->objectManager = GeneralUtility::makeInstance(
                'TYPO3\CMS\Extbase\Object\ObjectManager'
            );

            /* Get a fresh indexer instance from the ObjectManager */
            $indexer = $this->objectManager->get(
                'HSchulz\CustomKeSearchHooks\TypesFluidcontent',
                $indexerObject
            );

            /* Returns the indexer status */
            $content = $indexer->startIndexing();
        }

        return $content;
    }

}
