<?php

namespace HSchulz\CustomKeSearchHooks;

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

use HSchulz\CustomKeSearchHooks\RegisterFluidcontentIndexer;
use TYPO3\CMS\Core\Utility\ExtensionManagementUtility;

/* Oldschool require for non namespaced classes */
require_once(
    ExtensionManagementUtility::extPath('ke_search')
    . 'Classes/indexer/types/class.tx_kesearch_indexer_types_tt_content.php'
);

/**
 *
 * @author Hauke Schulz <hauke27@gmail.com>
 */
class TypesFluidcontent extends \tx_kesearch_indexer_types_tt_content {

    /**
     * Overwrites the parent implementation to set a the where clause for the
     * database query. The CType should match the type used by fluidcontent.
     *
     * @author Hauke Schulz <hauke27@gmail.com>
     * @param int $uid uid of page
     */
    public function getPageContent($uid) {

        /* Overwrite the where clause to only look for fluidcontent */
        $this->whereClauseForCType = sprintf(
            'CType="%s"',
            RegisterFluidcontentIndexer::INDEXER_TYPE
        );

        /* Now let the parent implementation work */
        parent::getPageContent($uid);
    }

    /**
     * Parses content from a fluidcontent_content element.<br>
     * The content string should come from the parent implementation of <br>
     * <code>
     * tx_kesearch_indexer_types_tt_content->getPageContent()
     * </code>
     *
     * @author Hauke Schulz <hauke27@gmail.com>
     * @param string $ttContentRow A row from tt_content
     * @return string the parsed content?
     */
    public function getContentFromContentElement($ttContentRow) {

        /* Parse the flexform data and return it */
        return $this->parseFlexformData($ttContentRow['pi_flexform']);
    }

    /**
     * Helper function to process the flexform data.
     *
     * @author Hauke Schulz <hauke27@gmail.com>
     * @param string $flexformData TYPO3 flexform data from tt_content
     * @return string
     */
    protected function parseFlexformData($flexformData) {

        /* Process the data */
        $parsedData = strip_tags(           // 3. strip html?
            html_entity_decode(             // 2. decode actual content?
                strip_tags($flexformData)   // 1. strip xml?
            )
        );

        /* Replace any kind of whitespace with a single space */
        $output = preg_replace('/\s\s+/', ' ', $parsedData);

        return $output;
    }
}
